@@ -2,6 +2,8 @@
 #' @description Download data sets from \href{https://ec.europa.eu/eurostat}{Eurostat} database .
 #' @param id A code name for the dataset of interest.
 #'        See \code{\link{search_eurostat_toc}} for details how to get an id.
+#' @param mode defines the format of the downloaded dataset. It can be \code{txt} (the default value) for TSV 
+#'        (Tab Separated Values), or \code{xml} for the SDMX version. 
 #' @param cache a logical whether to do caching. Default is \code{TRUE}.
 #' @param update_cache a logical with a default value \code{FALSE}, whether to update cache. Can be set also with
 #'        \code{options(restatapi_update=TRUE)}
@@ -56,6 +58,7 @@
 #' }
 
 get_eurostat_raw <- function(id, 
+                             mode="txt",
                              cache=TRUE, 
                              update_cache=FALSE,
                              cache_dir=NULL,
@@ -92,51 +95,122 @@ get_eurostat_raw <- function(id,
       }
     }
     if ((!cache)|(is.null(restat_raw))|(update_cache)){
-      bulk_url<-toc$downloadLink.sdmx[toc$code==id]
+      if (mode=="txt") {
+        bulk_url<-toc$downloadLink.tsv[toc$code==id]
+      } else if (mode=="xml") {
+        bulk_url<-toc$downloadLink.sdmx[toc$code==id]
+      } else {
+        bulk_url<-NULL
+        message("Incorrect mode:",mode,"\n It should be either 'txt' or 'xml'." )
+      }
       if (!is.null(bulk_url)){
-        temp <- tempfile()
-        if (verbose) {
-          message(nrow(toc),"bulk url: ",bulk_url)
-          tryCatch({utils::download.file(bulk_url,temp)},
-                   error = function(e) {
-                     message("Unable to download the SDMX file:",'\n',paste(unlist(e),collapse="\n"))
-                     ne<-FALSE
-                   },
-                   warning = function(w) {
-                     message("Unable to download the SDMX file:",'\n',paste(unlist(w),collapse="\n"))
-                   })
-        } else {
-          tryCatch({utils::download.file(bulk_url,temp)},
-                   error = function(e) {ne<-FALSE},
-                   warning = function(w) {})
-        }
-        if (ne) {
-          if (verbose) {
-            tryCatch({sdmx_file<-utils::unzip(temp, paste0(id,".sdmx.xml"))},
+        if (mode=="txt"){
+          temp <- tempfile()
+          if (verbose){
+            message("TOC rows: ",nrow(toc),"\nbulk url: ",bulk_url,"\ndata rowcount: ",toc$values[toc$code==id])
+            tryCatch({utils::download.file(bulk_url,temp)},
                      error = function(e) {
-                       message("Unable to unzip the SDMX file:",'\n',paste(unlist(e),collapse="\n"))
-                       ne2<-FALSE
+                       message("Unable to download the TSV file:",'\n',paste(unlist(e),collapse="\n"))
+                       ne<-FALSE
                      },
                      warning = function(w) {
-                       message("Unable to unzip the SDMX file:",'\n',paste(unlist(w),collapse="\n"))
+                       message("Unable to download the TSV file:",'\n',paste(unlist(w),collapse="\n"))
                      })
           } else {
-            tryCatch({sdmx_file<-utils::unzip(temp, paste0(id,".sdmx.xml"))},
-                     error = function(e) {ne2<-FALSE},
+            tryCatch({utils::download.file(bulk_url,temp)},
+                     error = function(e) {ne<-FALSE},
                      warning = function(w) {})
           }
-          if (ne2){
-            if(exists("sdmx_file")){
-              xml_leafs<-xml2::xml_find_all(xml2::read_xml(sdmx_file),".//data:Series")
-              unlink(temp)
-              unlink(paste0(id,".sdmx.xml"))
-              restat_raw<-data.table::rbindlist(parallel::mclapply(xml_leafs,extract_data,keep_flags=keep_flags,stringsAsFactors=stringsAsFactors,mc.cores=getOption("restatapi_cores",1L)))              
-            } else{
-              message("The SDMX file is missing. Check the file: ",temp)
+          if (ne){
+            if (verbose){
+              message("TOC rows: ",nrow(toc),"\nbulk url: ",bulk_url,"\ndata rowcount: ",toc$values[toc$code==id])
+              tryCatch({gz<-gzfile(temp, open = "rt")
+                        raw<-data.table::fread(text=readLines(gz),sep='\t',sep2=',',colClasses='character',header=TRUE)
+                        close(gz)
+                        unlink(temp)},
+                        error = function(e) {
+                        message("Unable to open the downloaded TSV file:",'\n',paste(unlist(e),collapse="\n"))
+                        ne2<-FALSE
+                       },
+                       warning = function(w) {
+                         message("Unable to open the downloaded TSV file:",'\n',paste(unlist(w),collapse="\n"))
+                       })
+            } else {
+              tryCatch({gz<-gzfile(temp, open = "rt")
+                        raw<-data.table::fread(text=readLines(gz),sep='\t',sep2=',',colClasses='character',header=TRUE)
+                        close(gz)
+                        unlink(temp)},
+                       error = function(e) {ne2<-FALSE},
+                       warning = function(w) {})
+            }
+          if (ne2) {
+            cname<-colnames(raw)[1] 
+            if (is.character(cname)){
+              cnames<-utils::head(unlist(strsplit(cname,(',|\\\\'))),-1)
+              rname<-utils::tail(unlist(strsplit(cname,(',|\\\\'))),1)
+              data.table::setnames(raw,1,"bdown")
+              raw_melted<-data.table::melt.data.table(raw,"bdown",variable.factor=stringsAsFactors)
+              rm(raw)
+              data.table::setnames(raw_melted,2:3,c(rname,"values"))
+              raw_melted<-raw_melted[raw_melted$values!=":",]
+              restat_raw<-data.table::as.data.table(data.table::tstrsplit(raw_melted$bdown,",",fixed=TRUE))
+              data.table::setnames(restat_raw,cnames)  
+              restat_raw<-data.table::data.table(restat_raw,raw_melted[,2:3])
+              if (keep_flags) {restat_raw$flags<-gsub('[0-9\\.-]',"",restat_raw$values)}
+              restat_raw$values<-gsub('[^0-9\\.-]',"",restat_raw$values)
+              restat_raw<-data.table(restat_raw,stringsAsFactors=stringsAsFactors)  
+            } else {
+              message("The file download was not successful. Try again later.")
+              restat_raw<-NULL
             }
           }  
+          }
+        } else if (mode=="xml"){
+          temp <- tempfile()
+          if (verbose) {
+            message("TOC rows: ",nrow(toc),"\nbulk url: ",bulk_url,"\ndata rowcount: ",toc$values[toc$code==id])
+            tryCatch({utils::download.file(bulk_url,temp)},
+                     error = function(e) {
+                       message("Unable to download the SDMX file:",'\n',paste(unlist(e),collapse="\n"))
+                       ne<-FALSE
+                     },
+                     warning = function(w) {
+                       message("Unable to download the SDMX file:",'\n',paste(unlist(w),collapse="\n"))
+                     })
+          } else {
+            tryCatch({utils::download.file(bulk_url,temp)},
+                     error = function(e) {ne<-FALSE},
+                     warning = function(w) {})
+          }
+          if (ne) {
+            if (verbose) {
+              tryCatch({sdmx_file<-utils::unzip(temp,paste0(id,".sdmx.xml"))},
+                       error = function(e) {
+                         message("Unable to unzip the SDMX file:",'\n',paste(unlist(e),collapse="\n"))
+                         ne2<-FALSE
+                       },
+                       warning = function(w) {
+                         message("Unable to unzip the SDMX file:",'\n',paste(unlist(w),collapse="\n"))
+                       })
+            } else {
+              tryCatch({sdmx_file<-utils::unzip(temp,paste0(id,".sdmx.xml"))},
+                       error = function(e) {ne2<-FALSE},
+                       warning = function(w) {})
+            }
+            if (ne2){
+              if(exists("sdmx_file")){
+                  xml_leafs<-xml2::xml_find_all(xml2::read_xml(sdmx_file),".//data:Series")
+                  unlink(temp)
+                  unlink(paste0(id,".sdmx.xml"))
+                  restat_raw<-data.table::rbindlist(parallel::mclapply(xml_leafs,extract_data,keep_flags=keep_flags,stringsAsFactors=stringsAsFactors,mc.cores=getOption("restatapi_cores",1L)))              
+                }
+              } else{
+                message("The data file is missing. Check the file: ",temp)
+              }
+            }
+          }
         }
-      }else{
+      else{
         message("The download link from the TOC is missing. Try again later.")
       }
     }  
